@@ -1,13 +1,9 @@
 package App::Netdisco::DB::ResultSet::DevicePort;
-use base 'App::Netdisco::DB::ResultSet';
+use base 'DBIx::Class::ResultSet';
 
 use strict;
 use warnings FATAL => 'all';
 
-__PACKAGE__->load_components(qw/
-  +App::Netdisco::DB::ExplicitLocking
-/);
-
 =head1 ADDITIONAL METHODS
 
 =head2 with_times
@@ -64,9 +60,9 @@ sub with_is_free {
     ->search({},
       {
         '+columns' => { is_free =>
-          \["me.up != 'up' and "
-              ."age(now(), to_timestamp(extract(epoch from device.last_discover) "
-                ."- (device.uptime - me.lastchange)/100)) "
+          \["up != 'up' and "
+              ."age(to_timestamp(extract(epoch from device.last_discover) "
+                ."- (device.uptime - lastchange)/100)) "
               ."> ?::interval",
             [{} => $interval]] },
         join => 'device',
@@ -93,11 +89,11 @@ sub only_free_ports {
     ->search_rs($cond, $attrs)
     ->search(
       {
-        'me.up' => { '!=' => 'up' },
+        'up' => { '!=' => 'up' },
       },{
         where =>
-          \["age(now(), to_timestamp(extract(epoch from device.last_discover) "
-                ."- (device.uptime - me.lastchange)/100)) "
+          \["age(to_timestamp(extract(epoch from device.last_discover) "
+                ."- (device.uptime - lastchange)/100)) "
               ."> ?::interval",
             [{} => $interval]],
       join => 'device' },
@@ -111,7 +107,7 @@ will add the following additional synthesized columns to the result set:
 
 =over 4
 
-=item vlan_count
+=item tagged_vlans_count
 
 =back
 
@@ -124,14 +120,14 @@ sub with_vlan_count {
     ->search_rs($cond, $attrs)
     ->search({},
       {
-        '+columns' => { vlan_count =>
-          $rs->result_source->schema->resultset('DevicePortVlan')
+        '+columns' => { tagged_vlans_count =>
+          $rs->result_source->schema->resultset('Virtual::DevicePortVlanTagged')
             ->search(
               {
-                'dpv.ip'   => { -ident => 'me.ip' },
-                'dpv.port' => { -ident => 'me.port' },
+                'dpvt.ip' => { -ident => 'me.ip' },
+                'dpvt.port' => { -ident => 'me.port' },
               },
-              { alias => 'dpv' }
+              { alias => 'dpvt' }
             )->count_rs->as_query
         },
       });
