@@ -3,6 +3,7 @@ package App::Netdisco::Web::Plugin::Report::DuplexMismatch;
 use Dancer ':syntax';
 use Dancer::Plugin::Ajax;
 use Dancer::Plugin::DBIC;
+use Dancer::Plugin::Auth::Extensible;
 
 use App::Netdisco::Web::Plugin;
 
@@ -12,7 +13,7 @@ register_report({
   label => 'Duplex Mismatches Between Devices',
 });
 
-ajax '/ajax/content/report/duplexmismatch' => sub {
+ajax '/ajax/content/report/duplexmismatch' => require_login sub {
     my $set = schema('netdisco')->resultset('Virtual::DuplexMismatch');
     return unless $set->count;
 
